isBasicItemType property
bool
get
isBasicItemType
Check if the field is a basic type (num, String, bool, int, double)
Implementation
bool get isBasicItemType => itemType.isBasicType;
Check if the field is a basic type (num, String, bool, int, double)
bool get isBasicItemType => itemType.isBasicType;