CvModelListField<T extends CvModel> class abstract

Nested list, where each value is of type T

Implemented types
Available extensions

Constructors

CvModelListField(String name, [T create(dynamic contentValue)?])
Only set value if not null
factory
CvModelListField.builder(String name, {CvModelBuilderFunction<T>? builder})
Only set value if not null, optional builder method
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasValue bool
True if a value is set (even if the value is null)
no setterinherited
isNotNull bool
Return true if set and not null
no setterinherited
isNull bool
Return true is null or unset
no setterinherited
itemType Type
List item type
no setterinherited
k String
The key (abbr.)
no setterinherited
key String
The key
no setterinherited
name String
Column name.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
Column type.
no setterinherited
v List<T>?
The value (abbr.)
getter/setter pairinherited
value List<T>?
The value
getter/setter pairinherited
valueOrNull List<T>?
The value or null if null or not set
getter/setter pairinherited
valueOrThrow List<T>
The value if available (nor null, nor not set).
getter/setter pairinherited

Methods

cast<RT>() CvField<RT>
Cast if needed
inherited
clear() → void
Clear value and flag
inherited
create(Map contentValue) → T
contentValue should be ignored or could be used to create the proper object but its content should not be populated.
createList() List<T>
List create helper
override
fromCvField(CvField<Object?> cvField) → void
Allow dynamic CvFields, copy if the value if set, otherwise delete it
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pathSubAt(int index) → T

Available on CvModelListField<T>, provided by the CvTreePathModelListFieldExt extension

Sub list index.
setNull() → void
Force the null value.
inherited
setValue(List<T>? value, {bool presentIfNull = false}) → void
presentIfNull true if null is marked as a value
inherited
toString() String
A string representation of this object.
inherited
withParent(String parent) CvField<List<T>>
Make the field an inner field, the parent being a map
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited