CvMultiField2<T1 extends Object?, T2 extends Object?> class abstract

A field that holds two values as a record.

Implemented types

Constructors

CvMultiField2(CvField<T1> field1, CvField<T2> field2)
Create a multi field.
factory

Properties

field1 CvField<T1>
Get field 1
no setter
field2 CvField<T2>
Get field 2
no setter
hashCode int
The hash code for this object.
no setterinherited
hasValue bool
True if a value is set (even if the value is null)
no setterinherited
isNotNull bool
Return true if set and not null
no setterinherited
isNull bool
Return true is null or unset
no setterinherited
k String
The key (abbr.)
no setterinherited
key String
The key
no setterinherited
multiField CvField<Object?>?
Get the multi field set
no setterinherited
multiValue Object?
Get the read value
no setterinherited
name String
Column name.
no setterinherited
rawValue Object?
Raw value (untyped)
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type Type
Column type.
no setterinherited
v ↔ (T1, T2)?
The value (abbr.)
getter/setter pairinherited
value ↔ (T1, T2)?
The value
getter/setter pairinherited
valueOrNull ↔ (T1, T2)?
The value or null if null or not set
getter/setter pairinherited
valueOrThrow ↔ (T1, T2)
The value if available (nor null, nor not set).
getter/setter pairinherited

Methods

cast<RT>() CvField<RT>
Cast if needed
inherited
clear() → void
Clear value and flag
inherited
fromCvField(CvField<Object?> cvField) → void
Allow dynamic CvFields, copy if the value if set, otherwise delete it
inherited
multiFromAnyValue(Object? value) → void
set content from any value
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setNull() → void
Force the null value.
inherited
setRawValue(Object? value, {bool presentIfNull = false}) → void
Set a value
inherited
setValue((T1, T2)? value, {bool presentIfNull = false}) → void
presentIfNull true if null is marked as a value
inherited
toString() String
A string representation of this object.
inherited
withParent(String parent) CvField<(T1, T2)>
Make the field an inner field, the parent being a map
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited