cv_matcher library

Functions

cvEquals(Object? expected) → CvModelMatcher
Returns a matches that matches if the value matches the expected Map or CvModel are expected and default to equals otherwise
cvEqualsDiffReport(Object? value, Object? expected) → String?
Diff report, null if the value matches the expected CvModel or Map are treated as equals
fillModelMatchesMap(Map map, [CvFillOptions? options]) → Matcher
Matches a map fill the model, handling any sort order of fields.