CvModelTreeValue<T extends CvModel, V extends Object?> class
abstract
A value wrapper for any element in the tree.
- Available extensions
Constructors
Properties
- found → bool
-
Could be found but null or unset
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasValue → bool
-
True if a value is set (even if the value is null)
no setterinherited
- listItemType → Type?
-
For list only, null otherwise
no setter
- model → T
-
The model
no setter
- rawValue → Object?
-
Raw value (untyped)
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- treePath → CvTreePath
-
The path
no setter
- type → Type
-
The type of the value
no setterinherited
- value → V?
-
Get a value
no setterinherited
Methods
-
clear(
) → void -
Clear value and flag
inherited
-
listCreateItem<
C> () → C -
Available on CvModelTreeValue<
Only valid if found is true andT, V> , provided by the CvModelTreeValueExt extensionvalueis a list -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setRawValue(
Object? value, {bool presentIfNull = false}) → void -
Set a value
inherited
-
setValue(
V? value, {bool presentIfNull = false}) → void - Set a value
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited